
# REST API Generator for Flask

REST API Generator will create API based on your [Schema](https://en.wikipedia.org/wiki/Database_schema) which can be run as a [Flask](https://github.com/pallets/flask) application.

Usage

```bash
RESTAPIGen <mysql_username> <mysql_password> <mysql_host> <mysql_db>
```
